@@ -1,16 +1,16 @@
 from .pipeline import BatchalignPipeline
 from .base import BatchalignEngine
 from .asr import (WhisperEngine, RevEngine, WhisperXEngine,
-                  TencentEngine, OAIWhisperEngine, AliyunEngine)
+                  TencentEngine, OAIWhisperEngine, AliyunEngine, FunAudioEngine)
 
 from .morphosyntax import StanzaEngine, CorefEngine
 from .cleanup import NgramRetraceEngine, DisfluencyReplacementEngine
 from .speaker import NemoSpeakerEngine
 
 from .fa import WhisperFAEngine, Wave2VecFAEngine
-from .utr import WhisperUTREngine, RevUTREngine, TencentUTREngine
+from .utr import WhisperUTREngine, RevUTREngine, TencentUTREngine, FunAudioUTREngine
 
 from .analysis import EvaluationEngine
 from .utterance import StanzaUtteranceEngine
 
-from .translate import SeamlessTranslationModel, GoogleTranslateEngine
+# from .translate import SeamlessTranslationModel, GoogleTranslateEngine
