@@ -72,6 +72,8 @@ def handler(word, lang=None):
     # if the lemma is ", return the word
     # not sure what errors are coming along?
     target = word.lemma
+    if target.strip() == "」" or target.strip() == "「":
+        target = word.text
 
     if target == '"':
         target = word.text
@@ -727,7 +729,7 @@ def morphoanalyze(doc: Document, retokenize:bool, skipmultilang:bool, status_hoo
                 pass
 
 
-# pycountry.languages.get(alpha_3=i).alpha_2 for i in lang
+    # pycountry.languages.get(alpha_3=i).alpha_2 for i in lang
 
     config = {"processors": {"tokenize": "default",
                              "pos": "default",
@@ -767,11 +769,17 @@ def morphoanalyze(doc: Document, retokenize:bool, skipmultilang:bool, status_hoo
         else:
             config["processors"]["mwt"] = "default"
 
+    if "ja" in lang:
+        config["processors"]["tokenize"] = "combined"
+        config["processors"]["pos"] = "combined"
+        config["processors"]["lemma"] = "combined"
+        config["processors"]["depparse"] = "combined"
+
+
     configs = {}
     for l in lang:
         configs[l] = config.copy()
 
-
     if len(lang) > 1:
         nlp = stanza.MultilingualPipeline(
             lang_configs = configs,
@@ -811,6 +819,9 @@ def morphoanalyze(doc: Document, retokenize:bool, skipmultilang:bool, status_hoo
             line_cut = i.strip(join_with_spaces=True)
         else:
             line_cut = i.strip(join_with_spaces=True)[:-len(ending)].strip()
+
+        # import ipdb
+        # ipdb.set_trace()
             # ending = ending.replace("+//", "")
 
         # if we don't have anything in line cut, just take the original
@@ -879,13 +890,13 @@ def morphoanalyze(doc: Document, retokenize:bool, skipmultilang:bool, status_hoo
 
             # parse the stanza output
             mor, gra = parse_sentence(sents[0], ending, special_forms_cleaned, lang[0])
+            mor = re.sub(r"~part\|s verb\|(\w+)-Ger-S", r"~aux|is verb|\1-Part-Pres-S", mor)
             # breakpoint()
 
             if mor.strip() == "" or mor.strip() in ENDING_PUNCT:
                 L.debug(f"Encountered an utterance that's likely devoid of morphological information; skipping... utterance='{doc.content[indx]}'")
                 continue
 
-
             if retokenize:
                 # rewrite the sentence with our desired tokenizations
                 ut, end = chat_parse_utterance(" ".join([i.text for i in sents[0].tokens])+" "+ending,
@@ -944,7 +955,7 @@ def morphoanalyze(doc: Document, retokenize:bool, skipmultilang:bool, status_hoo
                     # we want to replace the morphology of forms that are not actually
                     # supposed to be analyzed
                     elif isinstance(i, Extra) and i.extra_type == ExtraType.REFERENCE:
-                        if ut[i.payload].text != ",":
+                        if ut[i.payload].text not in MOR_PUNCT:
                             ut[i.payload].morphology = [Morphology(
                                 lemma = sents[0].tokens[i.payload].text if len(sents) > 0 and len(sents[0].tokens) > i.payload and sents[0].tokens[i.payload].text != "xbxxx" else ut[i.payload].text,
                                 pos = ut[i.payload].morphology[0].pos if (ut[i.payload].morphology and len(ut[i.payload].morphology) > 0) else "x",
